@@ -4,6 +4,7 @@ import pprint
 import sys
 import sysconfig
 import typing
+import unittest.mock
 from pathlib import Path
 from types import SimpleNamespace
 
@@ -17,7 +18,11 @@ from scikit_build_core.builder.sysconfig import (
 )
 from scikit_build_core.builder.wheel_tag import WheelTag
 from scikit_build_core.cmake import CMaker
-from scikit_build_core.settings.skbuild_model import ScikitBuildSettings, WheelSettings
+from scikit_build_core.settings.skbuild_model import (
+    BuildSettings,
+    ScikitBuildSettings,
+    WheelSettings,
+)
 
 
 # The envvar_higher case shouldn't happen, but the compiler should cause the
@@ -128,6 +133,19 @@ def test_builder_get_cmake_args(monkeypatch, cmake_args, answer):
     assert tmpbuilder.get_cmake_args() == answer
 
 
+def test_build_tool_args():
+    config = unittest.mock.create_autospec(CMaker)
+    settings = ScikitBuildSettings(build=BuildSettings(tool_args=["b"]))
+    tmpbuilder = Builder(
+        settings=settings,
+        config=typing.cast(CMaker, config),
+    )
+    tmpbuilder.build(["a"])
+    config.build.assert_called_once_with(
+        build_args=["a", "--", "b"], targets=[], verbose=settings.cmake.verbose
+    )
+
+
 @pytest.mark.parametrize(
     ("minver", "archs", "answer"),
     [
@@ -139,6 +157,12 @@ def test_builder_get_cmake_args(monkeypatch, cmake_args, answer):
     ],
 )
 def test_wheel_tag(monkeypatch, minver, archs, answer):
+    get_config_var = sysconfig.get_config_var
+    monkeypatch.setattr(
+        sysconfig,
+        "get_config_var",
+        lambda x: None if x == "Py_GIL_DISABLED" else get_config_var(x),
+    )
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", minver)
     monkeypatch.setattr(platform, "mac_ver", lambda: ("10.9.2", "", ""))
@@ -150,6 +174,12 @@ def test_wheel_tag(monkeypatch, minver, archs, answer):
 
 @pytest.mark.parametrize("archs", ["x86_64" "arm64" "universal2"])
 def test_wheel_build_tag(monkeypatch, archs):
+    get_config_var = sysconfig.get_config_var
+    monkeypatch.setattr(
+        sysconfig,
+        "get_config_var",
+        lambda x: None if x == "Py_GIL_DISABLED" else get_config_var(x),
+    )
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.12")
     monkeypatch.setattr(platform, "mac_ver", lambda: ("10.9.2", "", ""))
@@ -160,6 +190,12 @@ def test_wheel_build_tag(monkeypatch, archs):
 
 
 def test_wheel_tag_expand(monkeypatch):
+    get_config_var = sysconfig.get_config_var
+    monkeypatch.setattr(
+        sysconfig,
+        "get_config_var",
+        lambda x: None if x == "Py_GIL_DISABLED" else get_config_var(x),
+    )
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.10")
     monkeypatch.setattr(platform, "mac_ver", lambda: ("10.9.2", "", ""))
@@ -177,6 +213,12 @@ def test_wheel_tag_expand(monkeypatch):
 
 
 def test_wheel_tag_expand_11(monkeypatch):
+    get_config_var = sysconfig.get_config_var
+    monkeypatch.setattr(
+        sysconfig,
+        "get_config_var",
+        lambda x: None if x == "Py_GIL_DISABLED" else get_config_var(x),
+    )
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "11.2")
     monkeypatch.setattr(platform, "mac_ver", lambda: ("10.9.2", "", ""))
@@ -191,6 +233,12 @@ def test_wheel_tag_expand_11(monkeypatch):
 
 
 def test_wheel_tag_with_abi_darwin(monkeypatch):
+    get_config_var = sysconfig.get_config_var
+    monkeypatch.setattr(
+        sysconfig,
+        "get_config_var",
+        lambda x: None if x == "Py_GIL_DISABLED" else get_config_var(x),
+    )
     monkeypatch.setattr(sys, "platform", "darwin")
     monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.10")
     monkeypatch.setattr(platform, "mac_ver", lambda: ("10.9.2", "", ""))
