@@ -10,7 +10,7 @@ PROJECT_DIR = DIR / "packages" / "custom_cmake"
 
 
 def test_ep(isolated):
-    isolated.install("hatchling", "scikit-build-core[pyproject]")
+    isolated.install("hatchling", "scikit-build-core")
     isolated.install(PROJECT_DIR / "extern", isolated=False)
     isolated.install(PROJECT_DIR, "-v", isolated=False)
 
